/**************************************************************
 *
 * File: carr.h
 * Author: Steve Wolfman
 *
 * Description: Sample solution to CSE142 01sp project #1.  See
 * http://www.cs.washington.edu/142/ (navigate to hw#1, 01sp) for
 * description of assignment.
 *
 **************************************************************/

#include <stdio.h>    /* For I/O. */
#include <math.h>     /* For pow. */

/********* Useful constants **************/
#define USABLE_SPEED_RATIO     0.75   /* The fraction of max speed
                                         we're allowed to travel. */
#define COUNTERCLOCKWISE_BLOCK 25000  /* # of people for each ccw
                                         circle (1st step). */ 
#define CLOCKWISE_BLOCK        8000   /* # of people for each cw
                                         circle (2nd step). */
#define FORWARD_FRACTION       0.001  /* Percentage of population to
                                         travel forward (3rd step). */
#define PLAY_TIME              20.0   /* Seconds to play around (4th
                                         step). */
#define SIT_N_SPIN_ROT_SPEED   0.1    /* Speed to spin around for 4th
                                         step. */

/********* Main function *****************/
int main()
{
  double max_speed;        /* Maximum safe speed */
  double standard_speed;   /* Top usable speed */
  double time;             /* Time for each step (reused). */
  double rotational_speed; /* Rot. speed for each step (reused). */
  int population;          /* Alien population */
  int leftover_population; /* "Unused" pop. at each step. */
  int num_circles;         /* # of circles to make at each step (reused). */ 
  double perimeter;        /* Calc'd perimeter of the circles. */
  

  /**********************************
   *    Input                       *
   **********************************/
  
  /* Prompt for and read the maximum safe speed. */
  printf("Please enter the maximum safe speed for the robot: ");
  scanf("%lf", &max_speed);
  /* printf("Thanks for entering a max safe speed of %f.\n",
     max_speed); */

  /* Prompt for and read the population. */
  printf("Please enter the population of the alien planet: ");
  scanf("%d", &population);
  /* printf("Thanks for entering a population of %d.\n",
     population); */

  /**********************************
   *    Globally useful calcs       *
   **********************************/

  /* Calculate the speed that will actually be used. */
  standard_speed = max_speed * USABLE_SPEED_RATIO;
  /* printf("Usable speed is only %f.\n", standard_speed); */

  /**********************************
   *    First robot command         *
   **********************************/
  
  /* Calculate the number of counterclockwise circles to make. */
  num_circles = population / COUNTERCLOCKWISE_BLOCK + 1;
  /* printf("Number of counterclockwise circles is %d.\n", num_circles); */

  /* Calculate the perimeter of the circles. */
  perimeter = 1 + pow(population, 1.0 / 3.0);
  /* printf("Perimeter of circles is %f.\n", perimeter); */

  /* Calculate and print the parameters for the first circle. */
  time = num_circles * perimeter / standard_speed;
  rotational_speed = num_circles / time;
  printf("%f %f %f\n", standard_speed, rotational_speed, time);

  /**********************************
   *    Second robot command        *
   **********************************/

  /* Calculate the leftover population. */
  leftover_population = population % COUNTERCLOCKWISE_BLOCK;
  /* printf("Leftover population after first circles is %d.\n",
     leftover_population); */
  
  /* Calculate the number of circles for the second circle. */
  num_circles = leftover_population / CLOCKWISE_BLOCK + 1;
  /* printf("Number of clockwise circles is %d.\n",
     num_circles); */

  /* Calculate and print the parameters for the second circle. */
  time = num_circles * perimeter / standard_speed;
  rotational_speed = num_circles / time;
  /* Note the use of -rotational_speed to go clockwise. */
  printf("%f %f %f\n", standard_speed, -rotational_speed, time);

  /**********************************
   *    Third robot command         *
   **********************************/

  /* Calculate the time to drive forward. */
  leftover_population = leftover_population % CLOCKWISE_BLOCK;
  time = 1.0 * leftover_population * FORWARD_FRACTION;
  /* printf("Drive forward for %f seconds.\n", time); */

  /* Print the parameters for the straight line. */
  printf("%f %f %f\n", standard_speed, 0.0, time);

  /**********************************
   *    Fourth robot command        *
   **********************************/

  /* I'll have the robot spin in place for the fourth step. */
  printf("0.0 %f %f\n", SIT_N_SPIN_ROT_SPEED, PLAY_TIME);

  /**********************************
   *    Fifth robot command         *
   **********************************/

  /* Halt the robot. */
  printf("0.0 0.0 0.0\n");

  /* Report success. */
  return 0;
}

